@@ -1,74 +1,52 @@
 package Test::Chimps::Client;
 
-use 5.008;
 use warnings;
 use strict;
 
-our $VERSION = '0.11_01';
-
 use Carp;
 use Params::Validate qw/:all/;
-use HTTP::Request::Common;
+use Test::Chimps;
 use LWP::UserAgent;
+use Storable qw/nfreeze/;
 
-use constant PROTO_VERSION => 1.0;
+use constant PROTO_VERSION => 0.2;
 
 =head1 NAME
 
 Test::Chimps::Client - Send smoke test results to a server
 
+=head1 VERSION
+
+Version 0.02
+
+=cut
+
+our $VERSION = '0.02';
+
 =head1 SYNOPSIS
 
 This module simplifies the process of sending smoke test results
 (in the form of C<Test::TAP::Model>s) to a smoke server.
 
-    use File::Temp;
-    my $tmpfile = File::Temp->new( SUFFIX => ".tar.gz" );
-
-    use TAP::Harness::Archive;
-    chdir "some/module/directory";
-    my $harness = TAP::Harness::Archive->new( {
-        archive          => $tmpfile,
-        extra_properties => {
-            project   => 'my project',
-            revision  => 'some revision',
-            committer => 'me',
-            osname    => $Config{osname},
-            osvers    => $Config{osvers},
-            archname  => $Config{archname},
-        },
-        ....
-    } );
-    $harness->runtests(glob('t/*.t'));
-
     use Test::Chimps::Client;
+    use Test::TAP::Model::Visual;
+
+    chdir "some/module/directory";
+
+    my $model = Test::TAP::Model::Visual->new_with_tests(glob("t/*.t"));
+
     my $client = Test::Chimps::Client->new(
-        archive => $tmpfile,
-        server  => "http://...",
+      server => 'http://www.example.com/cgi-bin/smoke-server.pl',
+      model  => $model
     );
-
-    print "Sending smoke report for $server\n";
+    
     my ($status, $msg) = $client->send;
-    die "Error: the server responded: $msg\n"
-        unless $status;
+    
+    if (! $status) {
+      print "Error: $msg\n";
+      exit(1);
+    }
 
-=head1 INSTALLATION
-
-To install this module, run the following commands:
-
-    perl Makefile.PL
-    make
-    make test
-    make install
-
-=head1 DESCRIPTION
-
-Chimps is the Collaborative Heterogeneous Infinite Monkey
-Perfectionification Service.  It is a framework for storing,
-viewing, generating, and uploading smoke reports.
-
-This distribution provides client-side modules and binaries
-for Chimps.
 
 =head1 METHODS
 
@@ -78,16 +56,15 @@ Creates a new Client object.  ARGS is a hash whose valid keys are:
 
 =over 4
 
-=item * file
+=item * compress
+
+Optional.  Does not currently work
+
+=item * model
 
 Mandatory.  The value must be a C<Test::TAP::Model>.  These are the
 test results that will be submitted to the server.
 
-=item * report_variables
-
-Optional.  A hashref of report variables and values to send to the
-server.
-
 =item * server
 
 Mandatory.  The URI of the server script to upload the model to.
@@ -98,7 +75,7 @@ Mandatory.  The URI of the server script to upload the model to.
 
 use base qw/Class::Accessor/;
 
-__PACKAGE__->mk_ro_accessors(qw/archive server/);
+__PACKAGE__->mk_ro_accessors(qw/model server compress report_variables/);
 
 sub new {
   my $class = shift;
@@ -113,8 +90,9 @@ sub _init {
     params => \@_,
     called => 'The Test::Chimps::Client constructor',
     spec   => {
-      archive          => { isa => 'File::Temp' },
+      model            => { isa => 'Test::TAP::Model' },
       server           => 1,
+      compress         => 0,
       report_variables => {
         optional => 1,
         type     => HASHREF,
@@ -138,36 +116,32 @@ and the second of which is an error string.
 =cut
 
 sub send {
-    my $self = shift;
+  my $self = shift;
+  
+  my $ua = LWP::UserAgent->new;
+  $ua->agent("Test-Chimps-Client/" . PROTO_VERSION);
+  $ua->env_proxy;
 
-    my $ua = LWP::UserAgent->new;
-    $ua->agent( "Test-Chimps-Client/" . PROTO_VERSION );
-    $ua->env_proxy;
+  my %request = (upload => 1, version => PROTO_VERSION,
+                 model_structure => nfreeze($self->model->structure),
+                 report_variables => nfreeze($self->report_variables));
 
-    my $resp = $ua->post(
-        $self->server,
-        Content_Type => 'form-data',
-        Content      => [
-            upload  => 1,
-            archive => [ "$self->{archive}" ],
-            version => PROTO_VERSION
-        ],
-    );
-
-    if ( $resp->is_success ) {
-        if ( $resp->content =~ /^ok/ ) {
-            return ( 1, '' );
-        } else {
-            return ( 0, $resp->content );
-        }
+  my $resp = $ua->post($self->server => \%request);
+  if($resp->is_success) {
+    if($resp->content =~ /^ok/) {
+      return (1, '');
     } else {
-        return ( 0, $resp->status_line );
+      return (0, $resp->content);
     }
+  } else {
+    return (0, $resp->status_line);
+  }
 }
 
 =head1 ACCESSORS
 
-There are read-only accessors for model, report_variables, and server.
+There are read-only accessors for compress, model,
+report_variables, and server.
 
 =head1 AUTHOR
 
@@ -191,17 +165,6 @@ You can also look for information at:
 
 =over 4
 
-=item * Mailing list
-
-Chimps has a mailman mailing list at
-L<chimps@bestpractical.com>.  You can subscribe via the web
-interface at
-L<http://lists.bestpractical.com/cgi-bin/mailman/listinfo/chimps>.
-
-=item * Repository
-
-L<http://github.com/bestpractical/test-chimps-client>
-
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Test-Chimps-Client>
@@ -227,7 +190,7 @@ Pugs distribution.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2009 Best Practical Solutions.
+Copyright 2006 Best Practical Solutions.
 Portions copyright 2005-2006 the Pugs project.
 
 This program is free software; you can redistribute it and/or modify it
